# subread

**DOI:** [10.5281/zenodo.8037098](https://doi.org/10.5281/zenodo.8037098)

## Available Versions
- **Version 2.0.3**
  - [Download](https://zenodo.org/record/8037099/files/subread_2.0.3.img)
  - **MD5:** `f27f72595f4c0dc4265d62b9da566f47`
  - **DOI:** [10.5281/zenodo.8037099](https://doi.org/10.5281/zenodo.8037099)
  - **Size:** 145.34 MB
  - **Binaries:** 0 available

## Binaries (4 total)

```featureCounts subread-align subread-buildindex subread-fullscan```
